<?php
/**
 * Theme Framework functions and definitions
 *
 * Sets up the theme and provides some helper functions, which are used
 * in the theme as custom template tags. Others are attached to action and
 * filter hooks in WordPress to change core functionality.
 *
 * When using a child theme (see http://codex.wordpress.org/Theme_Development and
 * http://codex.wordpress.org/Child_Themes), you can override certain functions
 * (those wrapped in a function_exists() call) by defining them first in your child theme's
 * functions.php file. The child theme's functions.php file is included before the parent
 * theme's file, so the child theme functions would be used.
 *
 * Functions that are not pluggable (not wrapped in function_exists()) are instead attached
 * to a filter or action hook.
 *
 * For more information on hooks, actions, and filters, @link http://codex.wordpress.org/Plugin_API
 *
 * @package CMSSuperHeroes
 * @subpackage CMS Theme
 * @since 1.0.0
 */

// Set up the content width value based on the theme's design and stylesheet.
if ( ! isset( $content_width ) )
	$content_width = 625;
	
/**
 * CMS Theme setup.
 *
 * Sets up theme defaults and registers the various WordPress features that
 * CMS Theme supports.
 *
 * @uses load_theme_textdomain() For translation/localization support.
 * @uses add_editor_style() To add a Visual Editor stylesheet.
 * @uses add_theme_support() To add support for post thumbnails, automatic feed links,
 * 	custom background, and post formats.
 * @uses register_nav_menu() To add support for navigation menus.
 * @uses set_post_thumbnail_size() To set a custom post thumbnail size.
 *
 * @since 1.0.0
 */
function wage_setup() {

	// load language.
	load_theme_textdomain( 'wpwage' , get_template_directory() . '/languages' );

	// Adds title tag
	add_theme_support( "title-tag" );
	
	// Add woocommerce
	add_theme_support('woocommerce');
	
	// Adds custom header
	add_theme_support( 'custom-header' );
	
	// Adds RSS feed links to <head> for posts and comments.
	add_theme_support( 'automatic-feed-links' );

	// This theme supports a variety of post formats.
	add_theme_support( 'post-formats', array( 'video', 'audio' , 'gallery', 'quote') );

	// This theme uses wp_nav_menu() in one location.
	register_nav_menu( 'primary', esc_html__( 'Primary Menu', 'wpwage' ) );

	/*
	 * This theme supports custom background color and image,
	 * and here we also set up the default background color.
	 */
	add_theme_support( 'custom-background', array('default-color' => 'e6e6e6',) );

	// This theme uses a custom image size for featured images, displayed on "standard" posts.
	add_theme_support( 'post-thumbnails' );
	set_post_thumbnail_size( 624, 9999 ); // Unlimited height, soft crop

	add_image_size('wage-thumb-blog-mark', 553, 330, true);
	add_image_size('wage-thumb-project3', 553, 400, true);
	add_image_size('wage-thumb-services', 459, 353, true);
	add_image_size('wage-thumb-team', 400, 400, true);
	add_image_size('wage-thumb-service-slider', 850, 362, true);
	add_image_size('wage-thumb-blog-slider-layout2', 563, 520, true);
	
	update_option( 'large_size_w', 850); 
	update_option( 'large_size_h', 450);
	update_option( 'large_crop', 1);
	/* WooCommerce Thumbnail */
	$catalog = array(
        'width'     => '262',
        'height'    => '340',
        'crop'      => 1
    );
    $single = array(
        'width'     => '262',
        'height'    => '340',
        'crop'      => 1 
    );
    $thumbnail = array(
        'width'     => '150',
        'height'    => '150',
        'crop'      => 1
    );
    /* Image sizes */
    update_option( 'shop_catalog_image_size', $catalog );
    update_option( 'shop_single_image_size', $single );
    update_option( 'shop_thumbnail_image_size', $thumbnail );
	/*
	 * This theme styles the visual editor to resemble the theme style,
	 * specifically font, colors, icons, and column width.
	 */
	add_editor_style( array( 'assets/css/editor-style.css' ) );
}

add_action( 'after_setup_theme', 'wage_setup' );

/**
 * Enqueue scripts and styles for front-end.
 * @author Fox
 * @since CMS SuperHeroes 1.0
 */
function wage_front_end_scripts() {
    
	global $wp_styles, $opt_meta_options,$is_IE;

	/* one page. */
	if(is_page() && isset($opt_meta_options['page_one_page']) && $opt_meta_options['page_one_page']) {
		wp_register_script('jquery.singlePageNav', get_template_directory_uri() . '/assets/js/jquery.singlePageNav.js', array('jquery'), '1.2.0');
		wp_localize_script('jquery.singlePageNav', 'one_page_options', array('filter' => '.is-one-page', 'speed' => $opt_meta_options['page_one_page_speed']));
		wp_enqueue_script('jquery.singlePageNav');
	}
	/* Add pie.js */
	wp_enqueue_script('process-cycle', get_template_directory_uri() . '/assets/js/process_cycle.js', array(), '1.0.0', true);
	wp_enqueue_script('pie-custom', get_template_directory_uri() . '/assets/js/vc_pie_custom.js', array(), '1.0.0', true);
	/* Add pretyphoto.js */
	wp_enqueue_script('prettyPhoto', get_template_directory_uri() . '/assets/js/jquery.prettyPhoto.js', array('jquery'), '1.0.0', true);
	
	wp_enqueue_script('fitvids', get_template_directory_uri() . '/assets/js/jquery.fitvids.js', array('jquery'), '3.3.2');
	/* Adds Plugin JS Hoverdir. */
	wp_enqueue_script('wage-plugins', get_template_directory_uri() . '/assets/js/plugins.min.js', array('jquery'), '3.3.2');
	/* Add main.js */
	wp_enqueue_script( 'waypoints' );
	wp_enqueue_script('wp_wage-main', get_template_directory_uri() . '/assets/js/main.js', array('jquery'), '1.0.0', true);
	
	/* Add menu.js */
	wp_enqueue_script('wp_wage-menu', get_template_directory_uri() . '/assets/js/menu.js', array('jquery'), '1.0.0', true);
    
	/* Comment */
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) )
		wp_enqueue_script( 'comment-reply' );

	/** ----------------------------------------------------------------------------------- */
	
	/* Loads Bootstrap stylesheet. */
	wp_enqueue_style('bootstrap', get_template_directory_uri() . '/assets/css/bootstrap.min.css');
	/* Load manific popup css*/
	wp_enqueue_style('manific-popup', get_template_directory_uri() . '/assets/css/magnific-popup.css', array(), '1.0.0');
	/* Load prettyPhoto css*/
	wp_enqueue_style('prettyPhoto', get_template_directory_uri() . '/assets/css/prettyPhoto.css', array(), '1.0.0');
	/* Loads Bootstrap stylesheet. */
	wp_enqueue_style('font-awesome', get_template_directory_uri() . '/assets/css/font-awesome.min.css');
	/* Loads Font Stroke Gap Icon stylesheet. */

	/*Load Font Goodle----------*/
	
	wp_enqueue_style('owl-carousel', get_template_directory_uri() . '/assets/css/owl.carousel.min.css');
	/* Loads our main stylesheet. */
	wp_enqueue_style( 'wp_wage-style', get_stylesheet_uri());
	/* Loads Font Stroke Gap Icon stylesheet. */
	wp_enqueue_style('pe-icon-7-stroke', get_template_directory_uri() . '/assets/css/pe-icon-7-stroke.css', array(), '4.3.0');
	wp_enqueue_style('fontello', get_template_directory_uri() . '/assets/css/fontello.css', array(), '4.3.0');
	/*animation*/
	wp_enqueue_style('animate', get_template_directory_uri() . '/assets/css/animate.css', '', '1.0.0');

	/* ie */
	if($is_IE){
		wp_enqueue_style( 'wage-ie', get_template_directory_uri() . '/assets/css/ie.css', '1.0.0' );
	}
	
	/* Load static css*/
	wp_enqueue_style('wp_wage-static', get_template_directory_uri() . '/assets/css/static.css');
}

add_action( 'wp_enqueue_scripts', 'wage_front_end_scripts' );

/**
 * load admin scripts.
 * 
 * @author FOX
 */
function wage_admin_scripts(){

	/* Loads Bootstrap stylesheet. */
	wp_enqueue_style('font-awesome', get_template_directory_uri() . '/assets/css/font-awesome.min.css', array(), '4.3.0');
	/* Loads Font fontello stylesheet. */
	wp_enqueue_style('fontello', get_template_directory_uri() . '/assets/css/fontello.css', array(), '4.3.0');
	$screen = get_current_screen();

	/* load js for edit post. */
	if($screen->post_type == 'post'){
		/* post format select. */
		wp_enqueue_script('post-format', get_template_directory_uri() . '/assets/js/post-format.js', array(), '1.0.0', true);
	}
	/*countdown*/
	wp_register_style('jquery-datetimepicker', get_template_directory_uri().'/assets/css/countdown/jquery.datetimepicker.css');
    wp_enqueue_style('jquery-datetimepicker');
    wp_enqueue_script('wage-time', get_template_directory_uri() . '/assets/js/countdown/datetime-element.js');
}

add_action( 'admin_enqueue_scripts', 'wage_admin_scripts' );


/**
 * Add google font to theme 
 *
 * Montserrat
 * Poppins
 * Josefin Sans
 */
function wage_add_google_fonts() {
    wp_enqueue_style( 'source_sans_pro', 'https://fonts.googleapis.com/css?family=Source+Sans+Pro:200,200i,300,300i,400,400i,600,600i,700,700i,900,900i', false );
}
add_action( 'wp_enqueue_scripts', 'wage_add_google_fonts' );


/*----------------Call css VC admin------------------*/
function wage_register_scripts(){
  
    wp_enqueue_style('wage-admin-css', get_template_directory_uri() . '/assets/css/vc-admin.css', array(), '1.0.0');
}

add_action('init', 'wage_register_scripts');
/**
 * Load custom widget
 */
require( get_template_directory() . '/inc/widgets/cms-recentposts.php' );
require( get_template_directory() . '/inc/widgets/image/wage-image.php' );
require( get_template_directory() . '/inc/widgets/brochures.php' );
/*require( get_template_directory() . '/inc/widgets/cms-instagram.php' );*/
/**
 * Register sidebars.
 *
 * Registers our main widget area and the front page widget areas.
 *
 * @since Fox
 */
/**
 * Custom params & remove VC Elements.
 */
add_action('vc_before_init', 'wage_vc_after');

function wage_vc_after() {
    require( get_template_directory() . '/vc_params/cms_grid.php' );
    require( get_template_directory() . '/vc_params/cms_carousel.php' );
    require( get_template_directory() . '/vc_params/cms_fancybox_single.php' );
    require( get_template_directory() . '/vc_params/cms_counter_single.php' );
    require( get_template_directory() . '/vc_params/vc_custom_heading.php' );
    require( get_template_directory() . '/vc_params/vc_column_text.php' );
    require( get_template_directory() . '/vc_params/vc_tta_accordion.php' );
    require( get_template_directory() . '/vc_params/vc_tta_tabs.php' );
    require( get_template_directory() . '/vc_params/vc_pie.php' );
    require( get_template_directory() . '/vc_params/vc_row.php' );
    require( get_template_directory() . '/vc_params/vc_column_inner.php' );
    require( get_template_directory() . '/vc_params/vc_column.php' );
    require( get_template_directory() . '/vc_params/vc_btn.php' );
    require( get_template_directory() . '/vc_params/vc_single_image.php' );
    require( get_template_directory() . '/vc_params/cms_progressbar.php' );
    /* Add new VC Param Type */
		vc_add_shortcode_param( 'cms_time', 'wage_time_settings_field', get_template_directory_uri() . '/assets/js/countdown/jquery.datetimepicker.js' );
}
function wage_time_settings_field($settings, $value) {
    return '<div class="date-field cms_datetime_block" data-type="datetime" data-format="m/d/Y H:i">'
        	.'<input type="text" name="'.esc_attr( $settings['param_name']).'" class="wpb_vc_param_value wpb-textinput" value="'.esc_attr( $value ).'"/>'
        .'</div>';
}
/**
 * Add new elements for VC
 * 
 * @author FOX
 */
function wage_vc_before() {
    if(!class_exists('CmsShortCode'))
        return ;
    
    require( get_template_directory() . '/inc/elements/googlemaps/cms-googlemap.php' );
    require( get_template_directory() . '/inc/elements/cms_pricing.php' );
    require( get_template_directory() . '/inc/elements/cms_process.php' );
    require( get_template_directory() . '/inc/elements/cms_image_client.php' );
    require( get_template_directory() . '/inc/elements/cms_product_detail.php' );
    require( get_template_directory() . '/inc/elements/cms_countdown.php' );
}
add_action('vc_before_init', 'wage_vc_before');

/* Add Function Woo*/
/*/ Include woocommerce /*/
if (class_exists('Woocommerce')) {
	require_once( get_template_directory() . '/woocommerce/wc-function-hooks.php' );
	require_once( get_template_directory() . '/woocommerce/wc_template_hook.php' );
}

function wage_widgets_init() {

	global $opt_wage_options;

	register_sidebar( array(
		'name' => esc_html__( 'Main Sidebar', 'wpwage' ),
		'id' => 'sidebar-1',
		'description' => esc_html__( 'Appears on posts and pages except the optional Front Page template, which has its own widgets', 'wpwage' ),
		'before_widget' => '<aside  class="widget %2$s">',
		'after_widget' => '</aside>',
		'before_title' => '<h3 class="wg-title">',
		'after_title' => '</h3>',
	) );
	register_sidebar( array(
		'name' => esc_html__( 'Page Sidebar', 'wpwage' ),
		'id' => 'sidebar-project',
		'description' => esc_html__( 'Appears on posts and pages except the optional Front Page template, which has its own widgets', 'wpwage' ),
		'before_widget' => '<aside class="widget widget-page %2$s">',
		'after_widget' => '</aside>',
		'before_title' => '<h3 class="wg-title">',
		'after_title' => '</h3>',
	) );
	register_sidebar( array(
		'name' => esc_html__( 'Page About Sidebar', 'wpwage' ),
		'id' => 'sidebar-about',
		'description' => esc_html__( 'Appears on posts and pages except the optional Front Page template, which has its own widgets', 'wpwage' ),
		'before_widget' => '<aside class="widget widget-page %2$s">',
		'after_widget' => '</aside>',
		'before_title' => '<h3 class="wg-title">',
		'after_title' => '</h3>',
	) );

	register_sidebar( array(
		'name' => esc_html__( 'Cart', 'wpwage' ),
		'id' => 'sidebar-cart',
		'description' => esc_html__( 'Appears on posts and pages except the optional Front Page template, which has its own widgets', 'wpwage' ),
		'before_widget' => '<aside  class="widget %2$s">',
		'after_widget' => '</aside>',
		'before_title' => '<h3 class="wg-title">',
		'after_title' => '</h3>',
	) );

	register_sidebar( array(
		'name' => esc_html__( 'Search on Menu', 'wpwage' ),
		'id' => 'sidebar-search',
		'description' => esc_html__( 'Appears on posts and pages except the optional Front Page template, which has its own widgets', 'wpwage' ),
		'before_widget' => '<aside  class="widget %2$s">',
		'after_widget' => '</aside>',
		'before_title' => '<h3 class="wg-title">',
		'after_title' => '</h3>',
	) );

	/* footer-top */
	if(!empty($opt_wage_options['footer-top-column'])) {

		for($i = 1 ; $i <= $opt_wage_options['footer-top-column'] ; $i++){
			register_sidebar(array(
				'name' => sprintf(esc_html__('Footer Top %s', 'wpwage'), $i),
				'id' => 'sidebar-footer-top-' . $i,
				'description' => esc_html__('Appears on posts and pages except the optional Front Page template, which has its own widgets', 'wpwage'),
				'before_widget' => '<aside  class="widget %2$s">',
				'after_widget' => '</aside>',
				'before_title' => '<h3 class="wg-title">',
				'after_title' => '</h3>',
			));
		}
	}

	/* footer-top */
	if(!empty($opt_wage_options['footer-bottom-column'])) {

		for($i = 1 ; $i <= $opt_wage_options['footer-bottom-column'] ; $i++){
			register_sidebar(array(
				'name' => sprintf(esc_html__('Footer Bottom %s', 'wpwage'), $i),
				'id' => 'sidebar-footer-bottom-' . $i,
				'description' => esc_html__('Appears on posts and pages except the optional Front Page template, which has its own widgets', 'wpwage'),
				'before_widget' => '<aside  class="widget %2$s">',
				'after_widget' => '</aside>',
				'before_title' => '<h3 class="wg-title">',
				'after_title' => '</h3>',
			));
		}
	}
	if ( class_exists("woocommerce") ) {
		register_sidebar( array(
			'name' => esc_html__( 'Woocommerce Sidebar', 'wpwage' ),
			'id' => 'woocommerce_sidebar',
			'description' => esc_html__( 'Appears on pages except the optional Shop Page template, which has its own widgets', 'wpwage' ),
			'before_widget' => '<aside id="%1$s" class="widget %2$s">',
			'after_widget' => '</aside>',
			'before_title' => '<h3 class="wg-title">',
			'after_title' => '</h3>',
		) );
	}
}

add_action( 'widgets_init', 'wage_widgets_init' );

/**
 * Display navigation to next/previous comments when applicable.
 *
 * @since 1.0.0
 */
function wage_comment_nav() {
    // Are there comments to navigate through?
    if ( get_comment_pages_count() > 1 && get_option( 'page_comments' ) ) :
    ?>
	<nav class="navigation comment-navigation"  >
		<h2 class="screen-reader-text"><?php esc_html_e( 'Comment navigation', 'wpwage' ); ?></h2>
		<div class="nav-links">
			<?php
				if ( $prev_link = get_previous_comments_link( esc_html__( 'Older Comments', 'wpwage' ) ) ) :
					printf( '<div class="nav-previous">%s</div>', $prev_link );
				endif;

				if ( $next_link = get_next_comments_link( esc_html__( 'Newer Comments', 'wpwage' ) ) ) :
					printf( '<div class="nav-next">%s</div>', $next_link );
				endif;
			?>
		</div><!-- .nav-links -->
	</nav><!-- .comment-navigation -->
	<?php
	endif;
}

/**
 * Display navigation to next/previous set of posts when applicable.
 *
 * @since 1.0.0
 */
function wage_paging_nav() {
    // Don't print empty markup if there's only one page.
	if ( $GLOBALS['wp_query']->max_num_pages < 2 ) {
		return;
	}

	$paged        = get_query_var( 'paged' ) ? intval( get_query_var( 'paged' ) ) : 1;
	$pagenum_link = html_entity_decode( get_pagenum_link() );
	$query_args   = array();
	$url_parts    = explode( '?', $pagenum_link );

	if ( isset( $url_parts[1] ) ) {
		wp_parse_str( $url_parts[1], $query_args );
	}

	$pagenum_link = remove_query_arg( array_keys( $query_args ), $pagenum_link );
	$pagenum_link = trailingslashit( $pagenum_link ) . '%_%';

	// Set up paginated links.
	$links = paginate_links( array(
			'base'     => $pagenum_link,
			'total'    => $GLOBALS['wp_query']->max_num_pages,
			'current'  => $paged,
			'mid_size' => 1,
			'add_args' => array_map( 'urlencode', $query_args ),
			'prev_text' => '<i class="fa fa-long-arrow-left"></i>',
			'next_text' => '<i class="fa fa-long-arrow-right"></i>',
	) );

	if ( $links ) :

	?>
	<nav class="navigation paging-navigation clearfix"  >
		<div class="row">
			<div class="col-md-6 col-sm-12 col-xs-12">
				<div class="showing_result"><?php echo esc_html__('Showing ','wpwage') ?><?php wage_showing_result(); ?><?php echo esc_html__(' result','wpwage') ?></div>
			</div>
			<div class="col-md-6 col-sm-12 col-xs-12">
				<div class="pagination loop-pagination">
					<?php echo wp_kses_post($links); ?>
				</div><!-- .pagination -->
			</div>
		</div>
			
			
			
	</nav><!-- .navigation -->
	<?php
	endif;
}

/**
* Display navigation to next/previous post when applicable.
*
* @since 1.0.0
*/
function wage_post_nav() {
    global $post;

    // Don't print empty markup if there's nowhere to navigate.
    $previous = ( is_attachment() ) ? get_post( $post->post_parent ) : get_adjacent_post( false, '', true );
    $next     = get_adjacent_post( false, '', false );

    if ( ! $next && ! $previous )
        return;
    ?>
	<nav class="navigation post-navigation"  >
		<div class="nav-links clearfix">
			<?php
			$prev_post = get_previous_post();
			if (!empty( $prev_post )): ?>
			  <a class="btn btn-default post-prev left" href="<?php echo get_permalink( $prev_post->ID ); ?>"><i class="fa fa-angle-left"></i><?php echo esc_attr($prev_post->post_title); ?></a>
			<?php endif; ?>
			<?php
			$next_post = get_next_post();
			if ( is_a( $next_post , 'WP_Post' ) ) { ?>
			  <a class="btn btn-default post-next right" href="<?php echo get_permalink( $next_post->ID ); ?>"><?php echo get_the_title( $next_post->ID ); ?><i class="fa fa-angle-right"></i></a>
			<?php } ?>

			</div><!-- .nav-links -->
	</nav><!-- .navigation -->
	<?php
}
/**
* Display navigation to next/previous post when applicable.
*
* @since 1.0.0
*/
function wage_woo_post_nav() {
    global $post;

    // Don't print empty markup if there's nowhere to navigate.
    $previous = ( is_attachment() ) ? get_post( $post->post_parent ) : get_adjacent_post( false, '', true );
    $next     = get_adjacent_post( false, '', false );

    if ( ! $next && ! $previous )
        return;
    ?>
	<nav class="navigation post-navigation"  >
		<div class="nav-links clearfix">
			<?php
			$prev_post = get_previous_post();
			if (!empty( $prev_post )): ?>
			  <a class="post-prev left" href="<?php echo get_permalink( $prev_post->ID ); ?>"><i class="fa fa-long-arrow-left"></i></a>
			<?php endif; ?>
			<?php
			$next_post = get_next_post();
			if ( is_a( $next_post , 'WP_Post' ) ) { ?>
			  <a class="post-next right" href="<?php echo get_permalink( $next_post->ID ); ?>"><i class="fa fa-long-arrow-right"></i></a>
			<?php } ?>

			</div><!-- .nav-links -->
	</nav><!-- .navigation -->
	<?php
}

/* Add Custom Comment */
function wage_comment($comment, $args, $depth) {
	$GLOBALS['comment'] = $comment;
	extract($args, EXTR_SKIP);

	if ( 'div' == $args['style'] ) {
		$tag = 'div';
		$add_below = 'comment';
	} else {
		$tag = 'li';
		$add_below = 'div-comment';
	}
    ?>
    <<?php echo esc_attr($tag) ?> <?php comment_class( empty( $args['has_children'] ) ? '' : 'parent' ) ?> id="comment-<?php comment_ID() ?>">
    <?php if ( 'div' != $args['style'] ) : ?>
    <div id="div-comment-<?php comment_ID() ?>" class="comment-body clearfix">
    <?php endif; ?>
    <div class="comment-author-image vcard">
    	<?php echo get_avatar( $comment, 100 ); ?>
    	<div class="comment-meta commentmetadata">
    		<span class="comment-author"><?php echo get_comment_author_link(); ?></span>
    		
    		<div class="reply">
    			<span class="comment-date">
	    			<?php echo get_comment_date('j F Y \a\t h\.ia \/ '); ?>
	    		</span>
    			<span></span><?php comment_reply_link( array_merge( $args, array( 'add_below' => $add_below, 'depth' => $depth, 'max_depth' => $args['max_depth'] ) ) ); ?>
    		</div>
    	</div>
    </div>
    <?php if ( $comment->comment_approved == '0' ) : ?>
    	<em class="comment-awaiting-moderation"><?php esc_html_e( 'Your comment is awaiting moderation.' , 'wpwage'); ?></em>
    <?php endif; ?>
    <div class="comment-main">
    	<div class="comment-content">
    		<?php comment_text(); ?>
    	</div>
    </div>
    <?php if ( 'div' != $args['style'] ) : ?>
    </div>
    <?php endif; ?>
    <?php
}
/* core functions. */
require_once( get_template_directory() . '/inc/functions.php' );

/**
 * theme actions.
 */

/* add footer back to top. */
add_action('wp_footer', 'wage_footer_back_to_top');


add_filter('cms-shorcode-list', 'wage_shortcodes');
/**
 * support shortcodes
 * @return array
 */
function wage_shortcodes(){
	return array(
		'cms_carousel',
		'cms_grid',
		'cms_fancybox_single',
		'cms_counter_single',
		'cms_progressbar',
	);
}

function wage_footer_back_to_top(){
    global $opt_wage_options;

    $_back_to_top = true;

    if(isset($opt_wage_options['general_back_to_top']))
        $_back_to_top = $opt_wage_options['general_back_to_top'];

    if($_back_to_top)
        echo '<div class="ef3-back-to-top"><i class="fa fa-long-arrow-up"></i></div>';
}

function wage_footer_logo(){
    global $opt_wage_options;

}
/**
 * footer layout
 */
function wage_footer_top(){
    global $opt_wage_options;

	$footerlogo = (!empty($opt_wage_options['footerlogo']['url']))?$opt_wage_options['footerlogo']['url']:'';
	$footer_top_background_overlay = ((isset($opt_wage_options['footer_top_background_overlay'])) || (isset($opt_meta_options['footer_top_background_overlay'])))?'footer_top_background_overlay':'';


     if (empty($opt_wage_options['show_footer_top'])) {
    	return;
    }
     /* footer-top */
    if(empty($opt_wage_options['footer-top-column']))
        return;

	$_class = "";

    switch ($opt_wage_options['footer-top-column']){
        case '1':
            $_class = 'col-lg-12 col-md-12 col-sm-12 col-xs-12';
            break;
        case '2':
            $_class = 'col-lg-6 col-md-6 col-sm-6 col-xs-12';
            break;
        case '3':
            $_class = 'col-lg-4 col-md-4 col-sm-4 col-xs-12';
            break;
        case '4':
            $_class = 'col-lg-3 col-md-3 col-sm-6 col-xs-12';
            break;
    }
    ?>
    <div id="footer-top" class="<?php echo esc_attr($footer_top_background_overlay); ?>">
            <div class="container">
                <div class="row">
                    <?php
                   		for($i = 1 ; $i <= $opt_wage_options['footer-top-column'] ; $i++){
					      if ($i == 1) {
				        		echo '<div class="' . esc_html($_class) . '">';
				        			?>
				        			<div class="footer-top-1-wrap"> 
				        				<div class="footer-top-1-inner">
				        					<div class="inner">
						        				<a href="<?php echo get_home_url(); ?>" class="footer_logo"><img src="<?php echo esc_attr($footerlogo);?>" alt=""></a><?php

							        			if(is_active_sidebar( 'sidebar-footer-top-' . $i )){
							        				dynamic_sidebar( 'sidebar-footer-top-' . $i ); 
							        			} ?>
						        			</div>
			        					</div>
			        				</div><?php
					            echo "</div>";
					        	
					        }
				        	else if( is_active_sidebar( 'sidebar-footer-top-' . $i ) ){
					            echo '<div class="' . esc_html($_class) . '">';
					            dynamic_sidebar( 'sidebar-footer-top-' . $i );
					            echo "</div>";
					        }
					    }

                     ?>
    
                </div>
            </div>
        </div><!-- #footer-top -->
    <?php
}

function wage_footer_bottom(){
    global $opt_wage_options;
    if (empty($opt_wage_options['show_footer_bottom'])) {
    	return;
    }
    $class_fb ='col-md-6  col-sm-6 col-xs-12';
    if ((empty($opt_wage_options['copyright_footer'])) || (empty($opt_wage_options['enable_social_footer_bottom']))) {
    	$class_fb ='col-md-12  col-sm-12 col-xs-12 text-center';
    }
 ?>
    <div id="footer-bottom">
            <div class="container">
            	<div class="row">
            		<div class="<?php echo esc_attr($class_fb); ?>">
		              	<?php if (!empty($opt_wage_options['copyright_footer'])): ?>
					    	<div class="copyright-inner text-left">
							<?php echo wp_kses( $opt_wage_options['copyright_footer'], array('a' => array('href' => array(), 'title' => array() ), 'br' => array(), 'em' => array(), 'strong' => array() , 'ul' => array() , 'li' => array() ) ); ?>
							</div>
						<?php endif; ?>
					</div>
					<div class="<?php echo esc_attr($class_fb);?> text-right social_footer">
						<?php if (!empty($opt_wage_options['enable_social_footer_bottom']) && ($opt_wage_options['enable_social_footer_bottom']=="1")):
		            		wage_footer_bottom_social(); 
		            	endif; ?>
					</div>	
				</div>
				
            </div>
        </div><!-- #footer-bottom -->
    <?php
}
/**
 * get topbar social.
 */
function wage_footer_bottom_social(){
    global $opt_wage_options;
        ?>
        <ul class="social_footer">
            <?php
             if(!empty($opt_wage_options['enable_social_footer_bottom']) && $opt_wage_options['enable_social_footer_bottom']){ ?>
                <?php 
                $lists = array();
                $lists = ( !empty($opt_wage_options['individual_social_on_footer_bottom']['enabled']) ) ? $opt_wage_options['individual_social_on_footer_bottom']['enabled'] : '';
                
                if ( $lists ) {
                    foreach ($lists as $key => $value) {
                        switch ($key) {
                            case 'facebook-fb':
                                echo '<li class="'.esc_attr($key).' item"><a href="'.(!empty($opt_wage_options[$key])?esc_url($opt_wage_options[$key]):'#').'" target="_blank"><i class="fa fa-facebook"></i></a></li>';
                                break;
                            case 'twitter-fb':
                                echo '<li class="'.esc_attr($key).' item"><a href="'.(!empty($opt_wage_options[$key])?esc_url($opt_wage_options[$key]):'#').'" target="_blank"><i class="fa fa-twitter"></i></a></li>';
                                break;
                            case 'instagram-fb':
                                echo '<li class="'.esc_attr($key).' item"><a href="'.(!empty($opt_wage_options[$key])?esc_url($opt_wage_options[$key]):'#').'" target="_blank"><i class="fa fa-instagram"></i></a></li>';
                                break;
                            case 'pinterest-fb':
                                echo '<li class="'.esc_attr($key).' item"><a href="'.(!empty($opt_wage_options[$key])?esc_url($opt_wage_options[$key]):'#').'" target="_blank"><i class="fa fa-pinterest"></i></a></li>';
                                break;
                             case 'dribbble-fb':
                                echo '<li class="'.esc_attr($key).' item"><a href="'.(!empty($opt_wage_options[$key])?esc_url($opt_wage_options[$key]):'h#').'" target="_blank"><i class="fa fa-dribbble"></i></a></li>';
                                break;
                            case 'google-fb':
                                echo '<li class="'.esc_attr($key).' item"><a href="'.(!empty($opt_wage_options[$key])?esc_url($opt_wage_options[$key]):'h#').'" target="_blank"><i class="fa fa-google-plus"></i></a></li>';
                                break;
                            case 'youtube-fb':
                                echo '<li class="'.esc_attr($key).' item"><a href="'.(!empty($opt_wage_options[$key])?esc_url($opt_wage_options[$key]):'#').'" target="_blank"><i class="fa fa-youtube"></i></a></li>';
                                break;
                            case 'linkedin-fb':
                                echo '<li class="'.esc_attr($key).' item"><a href="'.(!empty($opt_wage_options[$key])?esc_url($opt_wage_options[$key]):'#').'" target="_blank"><i class="fa fa-linkedin"></i></a></li>';
                                break;
                        }
                    }
                }
                 ?>
            <?php } ?>
        </ul>    
        <?php
}
function wage_header_topbar() {
    global $opt_wage_options;

    if (!empty($opt_wage_options['enable_top_bar']) && ($opt_wage_options['enable_top_bar']=="1")): ?>
       
        <div id="top-bar" class="topbar hidden-xs hidden-sm">
        	<div class="top_bar_inner">
	            <ul class="top_bar">
	                <li class="social bord-none"> <?php wage_footer_bottom_social(); ?></li>
	                <?php if (!empty($opt_wage_options['topbar_info'])): ?>
	                    <li class="hidden-md hidden-sm hidden-xs bord-none" ><span><?php echo esc_html($opt_wage_options['topbar_info']); ?></span></li>
	                <?php endif; ?> 

	                <?php if (!empty($opt_wage_options['topbar_phone'])): ?>
	                    <li class="hidden-md hidden-sm hidden-xs" ><span><?php echo esc_html($opt_wage_options['topbar_phone']); ?></span></li>
	                <?php endif; ?>

	                <?php if (!empty($opt_wage_options['topbar_time'])): ?>
	                    <li class="hidden-md hidden-sm hidden-xs" ><span><?php echo esc_html($opt_wage_options['topbar_time']); ?></span></li>
	                <?php endif; ?>
	                <?php if ( class_exists('GTranslate') ) { ?>
	                	<li><?php wage_language();?></li>
	                <?php } ?>
	            </ul>
            </div>
        </div>
    <?php
    endif;   
}


function wage_language() {
	if ( class_exists('GTranslate') ) {
		echo do_shortcode('[gtranslate]');
	}
}
/**
 * Animation lib
 */
function wage_animate_lib() {
    $animate = array(
        esc_html__( 'None', 'wpwage' ) => 'cms_animate',
        esc_html__( 'Fade In Left', 'wpwage' ) => 'cms_animate fadeInLeft wow',
        esc_html__( 'Fade In Right', 'wpwage' ) => 'cms_animate fadeInRight wow',
        esc_html__( 'Fade In Up', 'wpwage' ) => 'cms_animate fadeInUp wow',
        esc_html__( 'Effect helix', 'wpwage' ) => 'cms_animate wow effect_helix',
        esc_html__( 'Zoom In', 'wpwage' ) => 'cms_animate zoomIn wow',
        esc_html__( 'Zoom Out', 'wpwage' ) => 'cms_animate zoomOut wow',
        esc_html__( 'Effect Pop', 'wpwage' ) => 'cms_animate wow effect-pop',
        esc_html__( 'Fade In Down', 'wpwage' ) => 'cms_animate wow fadeInDown',
        esc_html__( 'Fade In', 'wpwage' ) => 'cms_animate wow fadeIn',
        esc_html__( 'Fade Out', 'wpwage' ) => 'cms_animate wow fadeOut',
        esc_html__( 'Effect Fall', 'wpwage' ) => 'cms_animate wow effect-fall'
    );

    return $animate;
}

/**
 * Animation time delay lib
 */
function wage_animate_time_delay_lib() {
    $animate_time = array(
        esc_html__( 'None', 'wpwage' ) => '',
        esc_html__( '100ms', 'wpwage' ) => '100ms',
        esc_html__( '200ms', 'wpwage' ) => '200ms',
        esc_html__( '300ms', 'wpwage' ) => '300ms',
        esc_html__( '400ms', 'wpwage' ) => '400ms',
        esc_html__( '500ms', 'wpwage' ) => '500ms',
        esc_html__( '600ms', 'wpwage' ) => '600ms',
        esc_html__( '700ms', 'wpwage' ) => '700ms',
        esc_html__( '800ms', 'wpwage' ) => '800ms',
        esc_html__( '900ms', 'wpwage' ) => '900ms',
        esc_html__( '1s', 'wpwage' ) => '1s',
        esc_html__( '1.1s', 'wpwage' ) => '1.1s',
        esc_html__( '1.2s', 'wpwage' ) => '1.2s',
        esc_html__( '1.3s', 'wpwage' ) => '1.3s',
        esc_html__( '1.4s', 'wpwage' ) => '1.4s',
        esc_html__( '1.5s', 'wpwage' ) => '1.5s',
    );

    return $animate_time;
}
/**
 * Move comment field to bottom of Comment form
 */
function wage_move_comment_field_to_bottom( $fields ) {
    $comment_field = $fields['comment'];
    unset( $fields['comment'] );
    $fields['comment'] = $comment_field;

    return $fields;
}
add_filter( 'comment_form_fields', 'wage_move_comment_field_to_bottom' );

function wage_new_excerpt_more( $more ) {
    return '';
}
add_filter('excerpt_more', 'wage_new_excerpt_more');


/**
 * Display pagination information in the format "X - Y of Z".
 * 
 * @param object $wp_query Optionally generate string from custom query, defaults to main.
 */
function wage_showing_result( $wp_query = null ) {
    if ( ! $wp_query )
        global $wp_query;

    $posts = min( ( int ) $wp_query->get( 'posts_per_page' ), $wp_query->found_posts );
    $paged = max( ( int ) $wp_query->get( 'paged' ), 1 );
    $count = ( $paged - 1 ) * $posts;

    printf(
        '%d - %d of %d',
        $count + 1,
        $count + $wp_query->post_count,
        $wp_query->found_posts
    );
}
